@@ -88,7 +88,7 @@ class BilibiliParser(BaseParser):
     async def _parse_read(self, searched: Match[str]):
         """解析专栏信息"""
         read_id = int(searched.group("read_id"))
-        return await self.parse_read(read_id)
+        return await self.parse_read_with_opus(read_id)
 
     @handle("/opus/", r"bilibili\.com/opus/(?P<opus_id>\d+)")
     async def _parse_opus(self, searched: Match[str]):
@@ -175,14 +175,11 @@ class BilibiliParser(BaseParser):
         """
         from bilibili_api.dynamic import Dynamic
 
-        from .dynamic import DynamicItem
+        from .dynamic import DynamicData
 
         dynamic = Dynamic(dynamic_id, await self.credential)
+        dynamic_info = convert(await dynamic.get_info(), DynamicData).item
 
-        # 转换为结构体
-        dynamic_data = convert(await dynamic.get_info(), DynamicItem)
-        dynamic_info = dynamic_data.item
-        # 使用结构体属性提取信息
         author = self.create_author(dynamic_info.name, dynamic_info.avatar)
 
         # 下载图片
@@ -208,8 +205,8 @@ class BilibiliParser(BaseParser):
         opus = Opus(opus_id, await self.credential)
         return await self._parse_opus_obj(opus)
 
-    async def parse_read_old(self, read_id: int):
-        """解析专栏信息, 已废弃
+    async def parse_read_with_opus(self, read_id: int):
+        """解析专栏信息, 使用 Opus 接口
 
         Args:
             read_id (int): 专栏 id
@@ -297,45 +294,6 @@ class BilibiliParser(BaseParser):
             author=author,
         )
 
-    async def parse_read(self, read_id: int):
-        """专栏解析
-
-        Args:
-            read_id (int): 专栏 id
-
-        Returns:
-            texts: list[str], urls: list[str]
-        """
-        from bilibili_api.article import Article
-
-        from .article import TextNode, ImageNode, ArticleInfo
-
-        ar = Article(read_id)
-        # 加载内容
-        await ar.fetch_content()
-        data = ar.json()
-        article_info = convert(data, ArticleInfo)
-        logger.debug(f"article_info: {article_info}")
-
-        contents: list[MediaContent] = []
-        current_text = ""
-        for child in article_info.gen_text_img():
-            if isinstance(child, ImageNode):
-                contents.append(self.create_graphics_content(child.url, current_text.strip(), child.alt))
-                current_text = ""
-            elif isinstance(child, TextNode):
-                current_text += child.text
-
-        author = self.create_author(*article_info.author_info)
-
-        return self.result(
-            title=article_info.title,
-            timestamp=article_info.timestamp,
-            text=current_text.strip(),
-            author=author,
-            contents=contents,
-        )
-
     async def parse_favlist(self, fav_id: int):
         """解析收藏夹信息
 
