@@ -10,10 +10,10 @@ class TikTokParser(BaseParser):
     # 平台信息
     platform: ClassVar[Platform] = Platform(name=PlatformEnum.TIKTOK, display_name="TikTok")
 
-    @handle("tiktok.com", r"(?:https?://)?(www|vt|vm)\.tiktok\.com/[A-Za-z0-9._?%&+\-=/#@]*")
+    @handle("tiktok.com", r"(www|vt|vm)\.tiktok\.com/[A-Za-z0-9._?%&+\-=/#@]*")
     async def _parse(self, searched: re.Match[str]):
         # 从匹配对象中获取原始URL
-        url, prefix = searched.group(0), searched.group(1)
+        url, prefix = f"https://{searched.group(0)}", searched.group(1)
 
         if prefix in ("vt", "vm"):
             url = await self.get_redirect_url(url)
