@@ -30,13 +30,17 @@ class DefaultRenderer(BaseRenderer):
             texts.extend((result.display_url, result.repost_display_url))
 
         texts = [text for text in texts if text]
+        total_len = sum(len(text) for text in texts)
         texts[:-1] = [text + "\n" for text in texts[:-1]]
         segs: list[Segment] = [Text(text) for text in texts]
 
         if cover_path := await result.cover_path:
             segs.insert(1, UniHelper.img_seg(cover_path))
 
-        yield UniMessage(segs)
+        if total_len > 300:
+            yield UniMessage(UniHelper.construct_forward_message(segs))
+        else:
+            yield UniMessage(segs)
 
         async for message in self.render_contents(result):
             yield message
